// Copyright (c) 2016, 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
// This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
// Code generated. DO NOT EDIT.

package vulnerabilityscanning

import (
	"github.com/oracle/oci-go-sdk/v45/common"
	"net/http"
)

// ListHostEndpointProtectionScanResultsRequest wrapper for the ListHostEndpointProtectionScanResults operation
//
// See also
//
// Click https://docs.cloud.oracle.com/en-us/iaas/tools/go-sdk-examples/latest/vulnerabilityscanning/ListHostEndpointProtectionScanResults.go.html to see an example of how to use ListHostEndpointProtectionScanResultsRequest.
type ListHostEndpointProtectionScanResultsRequest struct {

	// The ID of the compartment in which to list resources.
	CompartmentId *string `mandatory:"true" contributesTo:"query" name:"compartmentId"`

	// The ID of a compute instance
	InstanceId *string `mandatory:"false" contributesTo:"query" name:"instanceId"`

	// Parameter to filter by highestProblemSeverity for scan results
	HighestProblemSeverity ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum `mandatory:"false" contributesTo:"query" name:"highestProblemSeverity" omitEmpty:"true"`

	// Date and time on or after which scans were started, as described in RFC 3339 (https://tools.ietf.org/rfc/rfc3339)
	TimeStartedGreaterThanOrEqualTo *common.SDKTime `mandatory:"false" contributesTo:"query" name:"timeStartedGreaterThanOrEqualTo"`

	// Date and time on or before which scans were started, as described in RFC 3339 (https://tools.ietf.org/rfc/rfc3339)
	TimeStartedLessThanOrEqualTo *common.SDKTime `mandatory:"false" contributesTo:"query" name:"timeStartedLessThanOrEqualTo"`

	// The sort order to use, either 'ASC' or 'DESC'.
	SortOrder ListHostEndpointProtectionScanResultsSortOrderEnum `mandatory:"false" contributesTo:"query" name:"sortOrder" omitEmpty:"true"`

	// The field to sort by. Only one sort order may be provided. Default order is descending. If no value is specified timeFinished is default.
	SortBy ListHostEndpointProtectionScanResultsSortByEnum `mandatory:"false" contributesTo:"query" name:"sortBy" omitEmpty:"true"`

	// The maximum number of items to return.
	Limit *int `mandatory:"false" contributesTo:"query" name:"limit"`

	// The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.
	Page *string `mandatory:"false" contributesTo:"query" name:"page"`

	// The client request ID for tracing.
	OpcRequestId *string `mandatory:"false" contributesTo:"header" name:"opc-request-id"`

	// A filter to return only resources that match the entire display name given.
	DisplayName *string `mandatory:"false" contributesTo:"query" name:"displayName"`

	// Metadata about the request. This information will not be transmitted to the service, but
	// represents information that the SDK will consume to drive retry behavior.
	RequestMetadata common.RequestMetadata
}

func (request ListHostEndpointProtectionScanResultsRequest) String() string {
	return common.PointerString(request)
}

// HTTPRequest implements the OCIRequest interface
func (request ListHostEndpointProtectionScanResultsRequest) HTTPRequest(method, path string, binaryRequestBody *common.OCIReadSeekCloser, extraHeaders map[string]string) (http.Request, error) {

	return common.MakeDefaultHTTPRequestWithTaggedStructAndExtraHeaders(method, path, request, extraHeaders)
}

// BinaryRequestBody implements the OCIRequest interface
func (request ListHostEndpointProtectionScanResultsRequest) BinaryRequestBody() (*common.OCIReadSeekCloser, bool) {

	return nil, false

}

// RetryPolicy implements the OCIRetryableRequest interface. This retrieves the specified retry policy.
func (request ListHostEndpointProtectionScanResultsRequest) RetryPolicy() *common.RetryPolicy {
	return request.RequestMetadata.RetryPolicy
}

// ListHostEndpointProtectionScanResultsResponse wrapper for the ListHostEndpointProtectionScanResults operation
type ListHostEndpointProtectionScanResultsResponse struct {

	// The underlying http response
	RawResponse *http.Response

	// A list of HostEndpointProtectionScanResultSummaryCollection instances
	HostEndpointProtectionScanResultSummaryCollection `presentIn:"body"`

	// Unique Oracle-assigned identifier for the request. If you need to contact
	// Oracle about a particular request, please provide the request ID.
	OpcRequestId *string `presentIn:"header" name:"opc-request-id"`

	// For pagination of a list of items. When paging through a list, if this header appears in the response,
	// then a partial list might have been returned. Include this value as the `page` parameter for the
	// subsequent GET request to get the next batch of items.
	OpcNextPage *string `presentIn:"header" name:"opc-next-page"`
}

func (response ListHostEndpointProtectionScanResultsResponse) String() string {
	return common.PointerString(response)
}

// HTTPResponse implements the OCIResponse interface
func (response ListHostEndpointProtectionScanResultsResponse) HTTPResponse() *http.Response {
	return response.RawResponse
}

// ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum Enum with underlying type: string
type ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum string

// Set of constants representing the allowable values for ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum
const (
	ListHostEndpointProtectionScanResultsHighestProblemSeverityNone     ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum = "NONE"
	ListHostEndpointProtectionScanResultsHighestProblemSeverityLow      ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum = "LOW"
	ListHostEndpointProtectionScanResultsHighestProblemSeverityMedium   ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum = "MEDIUM"
	ListHostEndpointProtectionScanResultsHighestProblemSeverityHigh     ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum = "HIGH"
	ListHostEndpointProtectionScanResultsHighestProblemSeverityCritical ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum = "CRITICAL"
)

var mappingListHostEndpointProtectionScanResultsHighestProblemSeverity = map[string]ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum{
	"NONE":     ListHostEndpointProtectionScanResultsHighestProblemSeverityNone,
	"LOW":      ListHostEndpointProtectionScanResultsHighestProblemSeverityLow,
	"MEDIUM":   ListHostEndpointProtectionScanResultsHighestProblemSeverityMedium,
	"HIGH":     ListHostEndpointProtectionScanResultsHighestProblemSeverityHigh,
	"CRITICAL": ListHostEndpointProtectionScanResultsHighestProblemSeverityCritical,
}

// GetListHostEndpointProtectionScanResultsHighestProblemSeverityEnumValues Enumerates the set of values for ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum
func GetListHostEndpointProtectionScanResultsHighestProblemSeverityEnumValues() []ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum {
	values := make([]ListHostEndpointProtectionScanResultsHighestProblemSeverityEnum, 0)
	for _, v := range mappingListHostEndpointProtectionScanResultsHighestProblemSeverity {
		values = append(values, v)
	}
	return values
}

// ListHostEndpointProtectionScanResultsSortOrderEnum Enum with underlying type: string
type ListHostEndpointProtectionScanResultsSortOrderEnum string

// Set of constants representing the allowable values for ListHostEndpointProtectionScanResultsSortOrderEnum
const (
	ListHostEndpointProtectionScanResultsSortOrderAsc  ListHostEndpointProtectionScanResultsSortOrderEnum = "ASC"
	ListHostEndpointProtectionScanResultsSortOrderDesc ListHostEndpointProtectionScanResultsSortOrderEnum = "DESC"
)

var mappingListHostEndpointProtectionScanResultsSortOrder = map[string]ListHostEndpointProtectionScanResultsSortOrderEnum{
	"ASC":  ListHostEndpointProtectionScanResultsSortOrderAsc,
	"DESC": ListHostEndpointProtectionScanResultsSortOrderDesc,
}

// GetListHostEndpointProtectionScanResultsSortOrderEnumValues Enumerates the set of values for ListHostEndpointProtectionScanResultsSortOrderEnum
func GetListHostEndpointProtectionScanResultsSortOrderEnumValues() []ListHostEndpointProtectionScanResultsSortOrderEnum {
	values := make([]ListHostEndpointProtectionScanResultsSortOrderEnum, 0)
	for _, v := range mappingListHostEndpointProtectionScanResultsSortOrder {
		values = append(values, v)
	}
	return values
}

// ListHostEndpointProtectionScanResultsSortByEnum Enum with underlying type: string
type ListHostEndpointProtectionScanResultsSortByEnum string

// Set of constants representing the allowable values for ListHostEndpointProtectionScanResultsSortByEnum
const (
	ListHostEndpointProtectionScanResultsSortByTimestarted     ListHostEndpointProtectionScanResultsSortByEnum = "timeStarted"
	ListHostEndpointProtectionScanResultsSortByTimefinished    ListHostEndpointProtectionScanResultsSortByEnum = "timeFinished"
	ListHostEndpointProtectionScanResultsSortByProblemseverity ListHostEndpointProtectionScanResultsSortByEnum = "problemSeverity"
)

var mappingListHostEndpointProtectionScanResultsSortBy = map[string]ListHostEndpointProtectionScanResultsSortByEnum{
	"timeStarted":     ListHostEndpointProtectionScanResultsSortByTimestarted,
	"timeFinished":    ListHostEndpointProtectionScanResultsSortByTimefinished,
	"problemSeverity": ListHostEndpointProtectionScanResultsSortByProblemseverity,
}

// GetListHostEndpointProtectionScanResultsSortByEnumValues Enumerates the set of values for ListHostEndpointProtectionScanResultsSortByEnum
func GetListHostEndpointProtectionScanResultsSortByEnumValues() []ListHostEndpointProtectionScanResultsSortByEnum {
	values := make([]ListHostEndpointProtectionScanResultsSortByEnum, 0)
	for _, v := range mappingListHostEndpointProtectionScanResultsSortBy {
		values = append(values, v)
	}
	return values
}
